RetryAttemptFailure

Enum RetryAttemptFailure 

pub enum RetryAttemptFailure<E> {
    Error(E),
    AttemptTimeout {
        elapsed: Duration,
        timeout: Duration,
    },
}
Failure produced by a single attempt.

The generic parameter E is the caller’s original application error type. Timeout failures do not contain an E value because they are produced by the retry executor while waiting for an asynchronous attempt.

Variants



Error(E)

The operation returned an application error.



AttemptTimeout

An async attempt exceeded the timeout passed to crate::RetryExecutor::run_async_with_timeout.

Fields

elapsed: Duration

Time observed by the retry executor for this attempt.

timeout: Duration

Configured timeout for one attempt.

Implementations

Source

impl<E> RetryAttemptFailure<E>

pub fn as_error(&self) -> Option<&E>

Returns the application error when this failure wraps one.

Parameters

This method has no parameters.

Returns

Some(&E) for RetryAttemptFailure::Error, or None for RetryAttemptFailure::AttemptTimeout.

Errors

This method does not return errors.

pub fn into_error(self) -> Option<E>

Consumes the failure and returns the application error when present.

Parameters

This method has no parameters.

Returns

Some(E) for RetryAttemptFailure::Error, or None for RetryAttemptFailure::AttemptTimeout.

Errors

This method does not return errors.