pub struct AttemptExecutorError { /* private fields */ }Expand description
Failure produced by the retry executor before an attempt can run normally.
This type is used for infrastructure failures such as failing to spawn a
worker thread for crate::Retry::run_in_worker.
Implementations