pub enum RetryErrorReason {
Aborted,
AttemptsExceeded,
MaxOperationElapsedExceeded,
MaxTotalElapsedExceeded,
UnsupportedOperation,
WorkerStillRunning,
}Expand description
Reason why the whole retry flow stopped with an error.
Variants
Aborted
A listener or retry policy aborted the retry flow.
AttemptsExceeded
No attempts remain.
MaxOperationElapsedExceeded
The cumulative user operation elapsed-time budget was exhausted.
MaxTotalElapsedExceeded
The total monotonic retry-flow elapsed-time budget was exhausted.
UnsupportedOperation
The operation mode does not support the configured behavior.
Currently used when Retry::run receives
configured per-attempt timeout options.
WorkerStillRunning
A timed-out blocking worker did not exit within the cancellation grace period.